# HoloOcean

[![Documentation Status](https://readthedocs.org/projects/holoocean/badge/?version=latest)](https://holoocean.readthedocs.io/en/latest/?badge=latest)


HoloOcean is a high-fidelity marine robotics simulator developed and maintained by the [BYU Field Robotic Systems Lab](https://frostlab.byu.edu/). Built on top of Unreal Engine 4 and extending Holodeck, HoloOcean provides the ability to simulate underwater robotic systems, sensors (including DVL, IMU, Sonar, Camera, Depth, etc), and communications with an easy-to-use interface.

Do to changes in the Unreal Engine EULA, HoloOcean is no longer released publicly via pypi, **however it is still open source and publicly avaliable via Github once you accept the Unreal EULA.**

__Please go to the official (readthedocs) documentation page for HoloOcean for instructions on the download process.__
